<?php
/*
    Time Machine list posts from past on WordPress blog's
    Copyright (C) 2009 Aleksandar Urošević <urke@users.sourceforge.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

Plugin Name: Time Machine
Version: 0.0.5.2
Plugin URI: http://blog.urosevic.net/wordpress/time-machine/
Author: Aleksandar Urošević
Author URI: http://urosevic.net/
Description: List all public posts published in past on today date, including all years of blogging
*/

function time_machine_init()
{
	if ( !function_exists("register_sidebar_widget") )
	return;
	register_sidebar_widget(__('Time Machine', 'tm'), "time_machine");
	register_widget_control(__('Time Machine', 'tm'), "tm_widget_control");
	load_plugin_textdomain('tm', PLUGINDIR.'/'.dirname(plugin_basename(__FILE__)).'/languages', dirname(plugin_basename(__FILE__)).'/languages');
}

function tm_widget_control()
{
	// Configuration panel for Time Machine Widget
	$options = get_option("time_machine");
	
	if ( !is_array( $options ) )
	{
		$options = array(
			"title"           => __('Time Machine', 'tm'),
			"message"         => __('No entry on current day in past', 'tm'),
			"posts"           => "10",
			"private"         => "0",
			"exclude_pages"   => "1",
			"exclude_current" => "0",
			"display_commentnum" => "0"
		);
		update_option("time_machine", $options);
	}

	if ( $_POST['tm-Submit'] )
	{
		$options['title']   = htmlspecialchars($_POST['tm-wTitle']);
		$options['message'] = htmlspecialchars($_POST['tm-wMessage']);
		$options['posts']   = htmlspecialchars($_POST['tm-wPosts']);
		$options['include_private'] = htmlspecialchars($_POST['tm-wIncludePrivate']);
		$options['exclude_pages']   = htmlspecialchars($_POST['tm-wExcludePages']);
		$options['exclude_current']   = htmlspecialchars($_POST['tm-wExcludeCurrent']);
		$options['display_commentnum']   = htmlspecialchars($_POST['tm-wDisplayCommentNum']);
		update_option("time_machine", $options);
	}

	?>
	<p>
	<label for="tm-wTitle"><?php _e('Title', 'tm'); ?>: </label><br />
	<input type="text" id="tm-wTitle" name="tm-wTitle" value="<?php echo $options['title'];?>" /><br /><br />
	<label for="tm-wPosts"><?php _e('Number of posts', 'tm'); ?>: </label><br />
	<input type="text" id="tm-wPosts" name="tm-wPosts" value="<?php echo $options['posts']; ?>" /><br />
	<em><?php _e('Default value is', 'tm'); ?> <strong>10</strong></em><br /><br />
	<label for="rm-wMessage"><?php _e('Message when no posts in past', 'tm'); ?></label><br />
	<input type="text" id="tm-wMessage" name="tm-wMessage" value="<?php echo $options['message']; ?>" /><br /><br />
	<input type="checkbox" id="tm-wIncludePrivate" name="tm-wIncludePrivate" value="1" <?php if ( $options['include_private'] == "1" ) { echo 'checked="yes"'; } ?> /> <label for="rm-wIncludePrivate"><?php _e('Include password protected posts in listing?', 'tm'); ?></label><br />
	<input type="checkbox" id="tm-wExcludePages" name="tm-wExcludePages" value="1" <?php if ( $options['exclude_pages'] == "1" ) { echo 'checked="yes"'; } ?> /> <label for="rm-wExcludePages"><?php _e('Exclude pages from listing', 'tm'); ?></label><br />
	<input type="checkbox" id="tm-wExcludeCurrent" name="tm-wExcludeCurrent" value="1" <?php if ( $options['exclude_current'] == "1" ) { echo 'checked="yes"'; } ?> /> <label for="rm-wExcludeCurrent"><?php _e('Exclude current year articles', 'tm'); ?></label><br />
	<input type="checkbox" id="tm-wDisplayCommentNum" name="tm-wDisplayCommentNum" value="1" <?php if ( $options['display_commentnum'] == "1" ) { echo 'checked="yes"'; } ?> /> <label for="rm-wDisplayCommentNum"><?php _e('Display number of comments', 'tm'); ?></label><br />
	<input type="hidden" id="tm-Submit" name="tm-Submit" value="1" />
	</p>
<?php
} // function tm_widget_control

function time_machine($args) {

	// get globals
	global $wpdb, $blog_url;
	
	// get widget options (title and number of post to list)
	$options = get_option("time_machine");

	// setup jocker date range
	$tm_time = "2%-".gmdate("m-d")." %:%:%";

	// display password protected posts or not?
	if ( $options['include_private'] <> "1" ) { $tm_private = "AND post_password=''"; } else { $tm_private = ""; }

	// exclude pages from listing?
	if ( $options['exclude_pages'] == "1" ) { $tm_pages = "AND post_type <> 'page'"; } else { $tm_pages = ""; }
	
	// do we need to exclude current year from query?
	if ( $options['exclude_current'] == "1" ) { $tm_current = "AND `post_date_gmt` NOT LIKE '".gmdate("Y")."-%-% %:%:%'"; } else { $tm_current = ""; }


	// setup SQL query
	$q = "SELECT ID, post_title, post_date, comment_count FROM $wpdb->posts WHERE post_status='publish' AND post_type <> 'attachment' $tm_private $tm_pages AND `post_date` LIKE '$tm_time' $tm_current ORDER BY `post_date` LIMIT ".$options['posts'];
	
	// extract WP args and print beginning of widget
	extract($args);
	echo "$before_widget $before_title ".$options['title']." $after_title<ul>";

	// execute SQL query and track error
	$r = $wpdb->get_results($q, OBJECT);
	
	// check if we got some posts
	if ( $r ) {
		// if we got posts, parse it
		foreach ( $r as $post )
		{
			// print formated post line
			if ( $options['display_commentnum'] == "1" ) { $pcount = ' (<span title="'.__("Number of comments", "5years").'">'.$post->comment_count.'</span>)'; } else { $pcount = ""; }
			echo '<li>'.substr($post->post_date,0,4).': <a href="'.$blog_url.'/?p='.$post->ID.'">'.$post->post_title.'</a>'.$pcount.'</li>';
		}
	} else {
		// if we have not blog posts on current date in past, print that info
		echo "<li>".$options['message']."</li>";
	}
	echo "</ul>$after_widget";
	
	// flush SQL query
	$wpdb->flush();
}

// Check for uninstall hook
if ( function_exists('register_uninstall_hook') )
	register_uninstall_hook(__FILE__, 'tm_uninstall');

// Delete options from database
function tm_uninstall()
{
	delete_option("time_machine");
}

// initialise Time Machin plugin
add_action("widgets_init", "time_machine_init");
?>
